Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
nexios\__init__.py | 19 | 0 | 0 | 100%
nexios\__main__.py | 9 | 6 | 0 | 33%
nexios\_utils\__init__.py | 0 | 0 | 0 | 100%
nexios\_utils\async_helpers.py | 53 | 18 | 11 | 66%
nexios\_utils\cuncurrency.py | 37 | 21 | 0 | 43%
nexios\application.py | 161 | 73 | 0 | 55%
nexios\auth\__init__.py | 4 | 0 | 0 | 100%
nexios\auth\backends\__init__.py | 2 | 0 | 0 | 100%
nexios\auth\backends\apikey.py | 17 | 10 | 0 | 41%
nexios\auth\backends\jwt.py | 44 | 5 | 0 | 89%
nexios\auth\base.py | 38 | 9 | 0 | 76%
nexios\auth\decorator.py | 29 | 5 | 0 | 83%
nexios\auth\exceptions.py | 13 | 0 | 0 | 100%
nexios\auth\middleware.py | 22 | 1 | 0 | 95%
nexios\config\__init__.py | 17 | 3 | 0 | 82%
nexios\config\base.py | 78 | 4 | 0 | 95%
nexios\converters.py | 75 | 32 | 2 | 57%
nexios\decorators.py | 55 | 24 | 0 | 56%
nexios\dependencies.py | 38 | 4 | 0 | 89%
nexios\events.py | 363 | 142 | 0 | 61%
nexios\exception_handler.py | 55 | 3 | 0 | 95%
nexios\exceptions.py | 25 | 7 | 0 | 72%
nexios\handlers\__init__.py | 0 | 0 | 0 | 100%
nexios\handlers\not_found.py | 34 | 11 | 0 | 68%
nexios\http\__init__.py | 3 | 0 | 0 | 100%
nexios\http\formparsers.py | 185 | 34 | 0 | 82%
nexios\http\request.py | 267 | 81 | 0 | 70%
nexios\http\response.py | 445 | 132 | 0 | 70%
nexios\logging.py | 42 | 14 | 0 | 67%
nexios\middlewares\__init__.py | 4 | 0 | 0 | 100%
nexios\middlewares\base.py | 18 | 1 | 0 | 94%
nexios\middlewares\core\__init__.py | 137 | 24 | 9 | 82%
nexios\middlewares\cors.py | 113 | 14 | 0 | 88%
nexios\middlewares\csrf.py | 82 | 58 | 0 | 29%
nexios\middlewares\errors\__init__.py | 0 | 0 | 0 | 100%
nexios\middlewares\errors\server_error_handler.py | 151 | 106 | 0 | 30%
nexios\openapi\__init__.py | 1 | 0 | 0 | 100%
nexios\openapi\_builder.py | 89 | 61 | 0 | 31%
nexios\openapi\config.py | 12 | 1 | 0 | 92%
nexios\openapi\models.py | 256 | 1 | 2 | 99%
nexios\pagination.py | 198 | 37 | 0 | 81%
nexios\routing.py | 433 | 157 | 0 | 64%
nexios\session\__init__.py | 0 | 0 | 0 | 100%
nexios\session\base.py | 126 | 49 | 0 | 61%
nexios\session\file.py | 55 | 20 | 0 | 64%
nexios\session\middleware.py | 37 | 2 | 0 | 95%
nexios\session\signed_cookies.py | 40 | 11 | 0 | 72%
nexios\status.py | 92 | 7 | 0 | 92%
nexios\structs.py | 460 | 208 | 0 | 55%
nexios\testing\__init__.py | 2 | 0 | 0 | 100%
nexios\testing\client.py | 30 | 0 | 0 | 100%
nexios\testing\transport.py | 251 | 164 | 0 | 35%
nexios\types.py | 18 | 0 | 0 | 100%
nexios\views.py | 41 | 11 | 0 | 73%
nexios\websockets\__init__.py | 9 | 0 | 0 | 100%
nexios\websockets\base.py | 137 | 104 | 0 | 24%
nexios\websockets\channels.py | 118 | 82 | 0 | 31%
nexios\websockets\consumers.py | 101 | 77 | 0 | 24%
nexios\websockets\errors.py | 25 | 15 | 0 | 40%
nexios\websockets\utils.py | 26 | 0 | 0 | 100%
test\__init__.py | 0 | 0 | 0 | 100%
test\test_application.py | 51 | 0 | 0 | 100%
test\test_auth.py | 145 | 6 | 0 | 96%
test\test_config.py | 50 | 0 | 0 | 100%
test\test_cors.py | 67 | 0 | 0 | 100%
test\test_dependencies.py | 102 | 2 | 0 | 98%
test\test_event.py | 64 | 0 | 0 | 100%
test\test_exception_handlers.py | 116 | 1 | 0 | 99%
test\test_form_parser.py | 230 | 3 | 0 | 99%
test\test_middlewares.py | 87 | 0 | 0 | 100%
test\test_pagination.py | 160 | 9 | 0 | 94%
test\test_request_objects.py | 112 | 0 | 0 | 100%
test\test_response.py | 85 | 0 | 0 | 100%
test\test_routing.py | 112 | 1 | 0 | 99%
test\test_session.py | 56 | 4 | 0 | 93%
Total | 6629 | 1875 | 24 | 72%

No items found using the specified filter.